// Importing necessary modules and libraries
const DeepLearnHub = require('deep-learn-hub');
const fs = require('fs');
const path = require('path');
const { PerformanceObserver, performance } = require('perf_hooks');
const readline = require('readline');

// Defining constants and configurations
const DATA_DIR = path.join(__dirname, 'data');
const OUTPUT_DIR = path.join(__dirname, 'output');
const TUTORIALS_DIR = path.join(DATA_DIR, 'tutorials');
const MODELS_DIR = path.join(DATA_DIR, 'pretrained_models');

// Creating a new DeepLearnHub instance with advanced configurations
const deepLearnHub = new DeepLearnHub({
  resources: true,
  tutorials: true,
  pretrainedModels: true
});

// Loading tutorials from directory
const tutorials = fs.readdirSync(TUTORIALS_DIR);

// Loading pretrained models from directory
const pretrainedModels = fs.readdirSync(MODELS_DIR);

// Starting performance monitoring
const obs = new PerformanceObserver((items) => {
  console.log(`Tutorials and pretrained models loaded in ${items.getEntries()[0].duration} milliseconds`);
  performance.clearMarks();
});
obs.observe({ entryTypes: ['measure'] });
performance.mark('start_load');

// Displaying available resources
console.log('Available Resources:');
console.log('Tutorials:');
for (const tutorial of tutorials) {
  console.log(`- ${tutorial}`);
}
console.log('Pretrained Models:');
for (const model of pretrainedModels) {
  console.log(`- ${model}`);
}

// Providing option for further exploration
const rl = readline.createInterface({
  input: process.stdin,
  output: process.stdout
});
rl.question('Do you want to explore tutorials or pretrained models? (tutorials/models/none): ', (answer) => {
  if (answer.toLowerCase() === 'tutorials') {
    deepLearnHub.exploreTutorials(tutorials);
  } else if (answer.toLowerCase() === 'models') {
    deepLearnHub.explorePretrainedModels(pretrainedModels);
  } else {
    console.log('Thank you for using DeepLearnHub. Happy learning!');
  }
  rl.close();
});

// Finishing performance monitoring
performance.mark('end_load');
performance.measure('Load Time', 'start_load', 'end_load');
